@@ -1,6 +1,6 @@
 /*  
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2014 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2015 by Paolo Lucente
 */
 
 /*
@@ -25,7 +25,7 @@
 /* includes */
 #include "pmacct.h"
 #include "bgp.h"
-#include "bgp_hash.h"
+#include "../bmp/bmp.h"
 #if defined WITH_RABBITMQ
 #include "amqp_common.h"
 #endif
@@ -60,7 +60,7 @@ int bgp_peer_log_msg(struct bgp_node *route, struct bgp_info *ri, safi_t safi, c
       kv = json_pack("{sI}", "seq", log_seq);
       json_object_update_missing(obj, kv);
       json_decref(kv);
-      bgp_peer_log_seq_increment();
+      bgp_peer_log_seq_increment(&log_seq);
 
       kv = json_pack("{ss}", "timestamp", log_tstamp_str);
       json_object_update_missing(obj, kv);
@@ -151,47 +151,83 @@ int bgp_peer_log_msg(struct bgp_node *route, struct bgp_info *ri, safi_t safi, c
   return (ret | amqp_ret);
 }
 
-int bgp_peer_log_init(struct bgp_peer *peer, int output)
+int bgp_peer_log_init(struct bgp_peer *peer, int output, int type)
 {
   int peer_idx, have_it, ret = 0, amqp_ret = 0;
   char log_filename[SRVBUFLEN], event_type[] = "log_init";
+  char peer_ip_src[] = "peer_ip_src", bmp_router[] = "bmp_router";
 
-  if (!peers_log || !peer || peer->log) return;
+  /* pointers to BGP or BMP vars */
+  struct bgp_peer_log **bpl;
+  char *file, *amqp_routing_key, *lts, *pa_str;
+  int amqp_routing_key_rr, max_peers;
+  u_int64_t *ls;
 
-  if (config.nfacctd_bgp_msglog_file)
-    bgp_peer_log_dynname(log_filename, SRVBUFLEN, config.nfacctd_bgp_msglog_file, peer); 
+  if (type == FUNC_TYPE_BGP) {
+    file = config.nfacctd_bgp_msglog_file;
+    amqp_routing_key = config.nfacctd_bgp_msglog_amqp_routing_key;
+    amqp_routing_key_rr = config.nfacctd_bgp_msglog_amqp_routing_key_rr;
+    max_peers = config.nfacctd_bgp_max_peers;
+    
+    pa_str = peer_ip_src;
+    lts = log_tstamp_str;
+    ls = &log_seq;
+    bpl = &peers_log;
+  }
+  else if (type == FUNC_TYPE_BMP) {
+    file = config.nfacctd_bmp_msglog_file;
+    amqp_routing_key = config.nfacctd_bmp_msglog_amqp_routing_key;
+    amqp_routing_key_rr = config.nfacctd_bmp_msglog_amqp_routing_key_rr;
+    max_peers = config.nfacctd_bmp_max_peers;
 
-  if (config.nfacctd_bgp_msglog_amqp_routing_key) {
-    bgp_peer_log_dynname(log_filename, SRVBUFLEN, config.nfacctd_bgp_msglog_amqp_routing_key, peer); 
+    pa_str = bmp_router;
+    lts = bmp_log_tstamp_str;
+    ls = &bmp_log_seq;
+    bpl = &bmp_peers_log;
+  }
+  else return ret;
+
+  if (!(*bpl) || !peer || peer->log) return;
+
+  if (file)
+    bgp_peer_log_dynname(log_filename, SRVBUFLEN, file, peer); 
+
+  if (amqp_routing_key) {
+    bgp_peer_log_dynname(log_filename, SRVBUFLEN, amqp_routing_key, peer); 
   }
 
-  for (peer_idx = 0, have_it = 0; peer_idx < config.nfacctd_bgp_max_peers; peer_idx++) {
-    if (!peers_log[peer_idx].refcnt) {
-      if (config.nfacctd_bgp_msglog_file)
-	peers_log[peer_idx].fd = open_logfile(log_filename, "a");
+  for (peer_idx = 0, have_it = 0; peer_idx < max_peers; peer_idx++) {
+    if (!(*bpl)[peer_idx].refcnt) {
+      if (file)
+	(*bpl)[peer_idx].fd = open_logfile(log_filename, "a");
 
 #ifdef WITH_RABBITMQ
-      if (config.nfacctd_bgp_msglog_amqp_routing_key)
-        peers_log[peer_idx].amqp_host = &bgp_daemon_msglog_amqp_host;
+      if (amqp_routing_key)
+        (*bpl)[peer_idx].amqp_host = &bgp_daemon_msglog_amqp_host;
 #endif
       
-      strcpy(peers_log[peer_idx].filename, log_filename);
+      strcpy((*bpl)[peer_idx].filename, log_filename);
       have_it = TRUE;
       break;
     }
-    else if (!strcmp(log_filename, peers_log[peer_idx].filename)) {
+    else if (!strcmp(log_filename, (*bpl)[peer_idx].filename)) {
       have_it = TRUE;
       break;
     }
   }
 
   if (have_it) {
-    peer->log = &peers_log[peer_idx];
-    peers_log[peer_idx].refcnt++;
+    peer->log = &(*bpl)[peer_idx];
+    (*bpl)[peer_idx].refcnt++;
 
 #ifdef WITH_RABBITMQ
-    if (config.nfacctd_bgp_msglog_amqp_routing_key)
+    if (amqp_routing_key)
       p_amqp_set_routing_key(peer->log->amqp_host, peer->log->filename);
+
+    if (amqp_routing_key_rr && !p_amqp_get_routing_key_rr(peer->log->amqp_host)) {
+      p_amqp_init_routing_key_rr(peer->log->amqp_host);
+      p_amqp_set_routing_key_rr(peer->log->amqp_host, amqp_routing_key_rr);
+    }
 #endif
 
     if (output == PRINT_OUTPUT_JSON) {
@@ -199,17 +235,17 @@ int bgp_peer_log_init(struct bgp_peer *peer, int output)
       char ip_address[INET6_ADDRSTRLEN];
       json_t *obj = json_object(), *kv;
 
-      kv = json_pack("{sI}", "seq", log_seq);
+      kv = json_pack("{sI}", "seq", (*ls));
       json_object_update_missing(obj, kv);
       json_decref(kv);
-      bgp_peer_log_seq_increment();
+      bgp_peer_log_seq_increment(ls);
 
-      kv = json_pack("{ss}", "timestamp", log_tstamp_str);
+      kv = json_pack("{ss}", "timestamp", lts);
       json_object_update_missing(obj, kv);
       json_decref(kv);
 
       addr_to_str(ip_address, &peer->addr);
-      kv = json_pack("{ss}", "peer_ip_src", ip_address);
+      kv = json_pack("{ss}", pa_str, ip_address);
       json_object_update_missing(obj, kv);
       json_decref(kv);
 
@@ -217,11 +253,11 @@ int bgp_peer_log_init(struct bgp_peer *peer, int output)
       json_object_update_missing(obj, kv);
       json_decref(kv);
 
-      if (config.nfacctd_bgp_msglog_file)
+      if (file)
 	write_and_free_json(peer->log->fd, obj);
 
 #ifdef WITH_RABBITMQ
-      if (config.nfacctd_bgp_msglog_amqp_routing_key) {
+      if (amqp_routing_key) {
 	amqp_ret = write_and_free_json_amqp(peer->log->amqp_host, obj); 
 	p_amqp_unset_routing_key(peer->log->amqp_host);
       }
@@ -233,17 +269,39 @@ int bgp_peer_log_init(struct bgp_peer *peer, int output)
   return (ret | amqp_ret);
 }
 
-int bgp_peer_log_close(struct bgp_peer *peer, int output)
+int bgp_peer_log_close(struct bgp_peer *peer, int output, int type)
 {
-  char event_type[] = "log_close";
+  char event_type[] = "log_close", peer_ip_src[] = "peer_ip_src", bmp_router[] = "bmp_router";
   struct bgp_peer_log *log_ptr;
   void *amqp_log_ptr;
   int ret = 0, amqp_ret = 0;;
 
-  if (!peers_log || !peer || !peer->log) return;
+  /* pointers to BGP or BMP vars */
+  char *file, *amqp_routing_key, *lts, *pa_str;
+  u_int64_t *ls;
+
+  if (type == FUNC_TYPE_BGP) {
+    file = config.nfacctd_bgp_msglog_file;
+    amqp_routing_key = config.nfacctd_bgp_msglog_amqp_routing_key;
+
+    pa_str = peer_ip_src;
+    lts = log_tstamp_str;
+    ls = &log_seq;
+  }
+  else if (type == FUNC_TYPE_BMP) {
+    file = config.nfacctd_bmp_msglog_file;
+    amqp_routing_key = config.nfacctd_bmp_msglog_amqp_routing_key;
+
+    pa_str = bmp_router;
+    lts = bmp_log_tstamp_str;
+    ls = &bmp_log_seq;
+  }
+  else return ret;
+
+  if (!peer || peer->log) return;
 
 #ifdef WITH_RABBITMQ
-  if (config.nfacctd_bgp_msglog_amqp_routing_key)
+  if (amqp_routing_key)
     p_amqp_set_routing_key(peer->log->amqp_host, peer->log->filename);
 #endif
 
@@ -259,17 +317,17 @@ int bgp_peer_log_close(struct bgp_peer *peer, int output)
     char ip_address[INET6_ADDRSTRLEN];
     json_t *obj = json_object(), *kv;
 
-    kv = json_pack("{sI}", "seq", log_seq);
+    kv = json_pack("{sI}", "seq", (*ls));
     json_object_update_missing(obj, kv);
     json_decref(kv);
-    bgp_peer_log_seq_increment();
+    bgp_peer_log_seq_increment(ls);
 
-    kv = json_pack("{ss}", "timestamp", log_tstamp_str);
+    kv = json_pack("{ss}", "timestamp", lts);
     json_object_update_missing(obj, kv);
     json_decref(kv);
 
     addr_to_str(ip_address, &peer->addr);
-    kv = json_pack("{ss}", "peer_ip_src", ip_address);
+    kv = json_pack("{ss}", pa_str, ip_address);
     json_object_update_missing(obj, kv);
     json_decref(kv);
 
@@ -277,11 +335,11 @@ int bgp_peer_log_close(struct bgp_peer *peer, int output)
     json_object_update_missing(obj, kv);
     json_decref(kv);
 
-    if (config.nfacctd_bgp_msglog_file)
+    if (file)
       write_and_free_json(log_ptr->fd, obj);
 
 #ifdef WITH_RABBITMQ
-    if (config.nfacctd_bgp_msglog_amqp_routing_key) {
+    if (amqp_routing_key) {
       amqp_ret = write_and_free_json_amqp(amqp_log_ptr, obj);
       p_amqp_unset_routing_key(amqp_log_ptr);
     }
@@ -290,7 +348,7 @@ int bgp_peer_log_close(struct bgp_peer *peer, int output)
   }
 
   if (!log_ptr->refcnt) {
-    if (config.nfacctd_bgp_msglog_file && !log_ptr->refcnt) {
+    if (file && !log_ptr->refcnt) {
       fclose(log_ptr->fd);
       memset(log_ptr, 0, sizeof(struct bgp_peer_log));
     }
@@ -299,16 +357,16 @@ int bgp_peer_log_close(struct bgp_peer *peer, int output)
   return (ret | amqp_ret);
 }
 
-void bgp_peer_log_seq_init()
+void bgp_peer_log_seq_init(u_int64_t *seq)
 {
-  log_seq = 0;
+  (*seq) = 0;
 }
 
-void bgp_peer_log_seq_increment()
+void bgp_peer_log_seq_increment(u_int64_t *seq)
 {
   /* Jansson does not support unsigned 64 bit integers, let's wrap at 2^63-1 */
-  if (log_seq == INT64T_THRESHOLD) log_seq = 0;
-  else log_seq++;
+  if ((*seq) == INT64T_THRESHOLD) (*seq) = 0;
+  else (*seq)++;
 }
 
 void bgp_peer_log_dynname(char *new, int newlen, char *old, struct bgp_peer *peer)
@@ -347,16 +405,43 @@ void bgp_peer_log_dynname(char *new, int newlen, char *old, struct bgp_peer *pee
   }
 }
 
-int bgp_peer_dump_init(struct bgp_peer *peer, int output)
+int bgp_peer_dump_init(struct bgp_peer *peer, int output, int type)
 {
-  char event_type[] = "dump_init";
+  char event_type[] = "dump_init", peer_ip_src[] = "peer_ip_src", bmp_router[] = "bmp_router";
   int ret = 0, amqp_ret = 0;
 
+  /* pointers to BGP or BMP vars */
+  char *amqp_routing_key, *file, *pa_str, *lts;
+  int amqp_routing_key_rr;
+
   if (!peer || !peer->log) return;
 
+  if (type == FUNC_TYPE_BGP) {
+    amqp_routing_key = config.bgp_table_dump_amqp_routing_key;
+    amqp_routing_key_rr = config.bgp_table_dump_amqp_routing_key_rr;
+    file = config.bgp_table_dump_file;
+
+    pa_str = peer_ip_src;
+    lts = log_tstamp_str; 
+  }
+  else if (type == FUNC_TYPE_BMP) {
+    amqp_routing_key = config.bmp_dump_amqp_routing_key;
+    amqp_routing_key_rr = config.bmp_dump_amqp_routing_key_rr;
+    file = config.bmp_dump_file;
+
+    pa_str = bmp_router;
+    lts = bmp_log_tstamp_str;
+  }
+  else return ret;
+
 #ifdef WITH_RABBITMQ
-  if (config.bgp_table_dump_amqp_routing_key)
+  if (amqp_routing_key)
     p_amqp_set_routing_key(peer->log->amqp_host, peer->log->filename);
+
+  if (amqp_routing_key_rr && !p_amqp_get_routing_key_rr(peer->log->amqp_host)) {
+    p_amqp_init_routing_key_rr(peer->log->amqp_host);
+    p_amqp_set_routing_key_rr(peer->log->amqp_host, amqp_routing_key_rr);
+  }
 #endif
 
   if (output == PRINT_OUTPUT_JSON) {
@@ -364,12 +449,12 @@ int bgp_peer_dump_init(struct bgp_peer *peer, int output)
     char ip_address[INET6_ADDRSTRLEN];
     json_t *obj = json_object(), *kv;
 
-    kv = json_pack("{ss}", "timestamp", log_tstamp_str);
+    kv = json_pack("{ss}", "timestamp", lts);
     json_object_update_missing(obj, kv);
     json_decref(kv);
 
     addr_to_str(ip_address, &peer->addr);
-    kv = json_pack("{ss}", "peer_ip_src", ip_address);
+    kv = json_pack("{ss}", pa_str, ip_address);
     json_object_update_missing(obj, kv);
     json_decref(kv);
 
@@ -377,11 +462,11 @@ int bgp_peer_dump_init(struct bgp_peer *peer, int output)
     json_object_update_missing(obj, kv);
     json_decref(kv);
 
-    if (config.bgp_table_dump_file)
+    if (file)
       write_and_free_json(peer->log->fd, obj);
 
 #ifdef WITH_RABBITMQ
-    if (config.bgp_table_dump_amqp_routing_key) {
+    if (amqp_routing_key) {
       amqp_ret = write_and_free_json_amqp(peer->log->amqp_host, obj);
       p_amqp_unset_routing_key(peer->log->amqp_host);
     }
@@ -392,15 +477,34 @@ int bgp_peer_dump_init(struct bgp_peer *peer, int output)
   return (ret | amqp_ret);
 }
 
-int bgp_peer_dump_close(struct bgp_peer *peer, int output)
+int bgp_peer_dump_close(struct bgp_peer *peer, int output, int type)
 {
-  char event_type[] = "dump_close";
+  char event_type[] = "dump_close", peer_src_ip[] = "peer_src_ip", bmp_router[] = "bmp_router";
   int ret = 0, amqp_ret = 0;
 
+  /* pointers to BGP or BMP vars */
+  char *amqp_routing_key, *file, *pa_str, *lts;
+
   if (!peer || !peer->log) return;
 
+  if (type == FUNC_TYPE_BGP) {
+    amqp_routing_key = config.bgp_table_dump_amqp_routing_key; 
+    file = config.bgp_table_dump_file;
+
+    pa_str = peer_src_ip;
+    lts = log_tstamp_str;
+  }
+  else if (type == FUNC_TYPE_BMP) {
+    amqp_routing_key = config.bmp_dump_amqp_routing_key;
+    file = config.bmp_dump_file;
+
+    pa_str = bmp_router;
+    lts = bmp_log_tstamp_str;
+  }
+  else return ret;
+
 #ifdef WITH_RABBITMQ
-  if (config.bgp_table_dump_amqp_routing_key)
+  if (amqp_routing_key)
     p_amqp_set_routing_key(peer->log->amqp_host, peer->log->filename);
 #endif
 
@@ -409,7 +513,7 @@ int bgp_peer_dump_close(struct bgp_peer *peer, int output)
     char ip_address[INET6_ADDRSTRLEN];
     json_t *obj = json_object(), *kv;
 
-    kv = json_pack("{ss}", "timestamp", log_tstamp_str);
+    kv = json_pack("{ss}", "timestamp", lts);
     json_object_update_missing(obj, kv);
     json_decref(kv);
 
@@ -422,11 +526,11 @@ int bgp_peer_dump_close(struct bgp_peer *peer, int output)
     json_object_update_missing(obj, kv);
     json_decref(kv);
 
-    if (config.bgp_table_dump_file)
+    if (file)
       write_and_free_json(peer->log->fd, obj);
 
 #ifdef WITH_RABBITMQ
-    if (config.bgp_table_dump_amqp_routing_key) {
+    if (amqp_routing_key) {
       amqp_ret = write_and_free_json_amqp(peer->log->amqp_host, obj);
       p_amqp_unset_routing_key(peer->log->amqp_host);
     }
@@ -515,7 +619,7 @@ void bgp_handle_dump_event()
 	}
 #endif
 
-	bgp_peer_dump_init(peer, config.bgp_table_dump_output);
+	bgp_peer_dump_init(peer, config.bgp_table_dump_output, FUNC_TYPE_BGP);
 
 	for (afi = AFI_IP; afi < AFI_MAX; afi++) {
 	  for (safi = SAFI_UNICAST; safi < SAFI_MAX; safi++) {
@@ -542,7 +646,7 @@ void bgp_handle_dump_event()
 
         saved_peer = peer;
         strlcpy(last_filename, current_filename, SRVBUFLEN);
-        bgp_peer_dump_close(peer, config.bgp_table_dump_output);
+        bgp_peer_dump_close(peer, config.bgp_table_dump_output, FUNC_TYPE_BGP);
 	tables_num++;
       }
     }
@@ -576,14 +680,17 @@ void bgp_daemon_msglog_init_amqp_host()
   if (!config.nfacctd_bgp_msglog_amqp_exchange) config.nfacctd_bgp_msglog_amqp_exchange = default_amqp_exchange;
   if (!config.nfacctd_bgp_msglog_amqp_exchange_type) config.nfacctd_bgp_msglog_amqp_exchange_type = default_amqp_exchange_type;
   if (!config.nfacctd_bgp_msglog_amqp_host) config.nfacctd_bgp_msglog_amqp_host = default_amqp_host;
+  if (!config.nfacctd_bgp_msglog_amqp_vhost) config.nfacctd_bgp_msglog_amqp_vhost = default_amqp_vhost;
 
   p_amqp_set_user(&bgp_daemon_msglog_amqp_host, config.nfacctd_bgp_msglog_amqp_user);
   p_amqp_set_passwd(&bgp_daemon_msglog_amqp_host, config.nfacctd_bgp_msglog_amqp_passwd);
   p_amqp_set_exchange(&bgp_daemon_msglog_amqp_host, config.nfacctd_bgp_msglog_amqp_exchange);
   p_amqp_set_exchange_type(&bgp_daemon_msglog_amqp_host, config.nfacctd_bgp_msglog_amqp_exchange_type);
   p_amqp_set_host(&bgp_daemon_msglog_amqp_host, config.nfacctd_bgp_msglog_amqp_host);
+  p_amqp_set_vhost(&bgp_daemon_msglog_amqp_host, config.nfacctd_bgp_msglog_amqp_vhost);
   p_amqp_set_persistent_msg(&bgp_daemon_msglog_amqp_host, config.nfacctd_bgp_msglog_amqp_persistent_msg);
   p_amqp_set_frame_max(&bgp_daemon_msglog_amqp_host, config.nfacctd_bgp_msglog_amqp_frame_max);
+  p_amqp_set_heartbeat_interval(&bgp_daemon_msglog_amqp_host, config.nfacctd_bgp_msglog_amqp_heartbeat_interval);
 }
 #else
 void bgp_daemon_msglog_init_amqp_host()
@@ -601,14 +708,17 @@ void bgp_table_dump_init_amqp_host()
   if (!config.bgp_table_dump_amqp_exchange) config.bgp_table_dump_amqp_exchange = default_amqp_exchange;
   if (!config.bgp_table_dump_amqp_exchange_type) config.bgp_table_dump_amqp_exchange_type = default_amqp_exchange_type;
   if (!config.bgp_table_dump_amqp_host) config.bgp_table_dump_amqp_host = default_amqp_host;
+  if (!config.bgp_table_dump_amqp_vhost) config.bgp_table_dump_amqp_vhost = default_amqp_vhost;
 
   p_amqp_set_user(&bgp_table_dump_amqp_host, config.bgp_table_dump_amqp_user);
   p_amqp_set_passwd(&bgp_table_dump_amqp_host, config.bgp_table_dump_amqp_passwd);
   p_amqp_set_exchange(&bgp_table_dump_amqp_host, config.bgp_table_dump_amqp_exchange);
   p_amqp_set_exchange_type(&bgp_table_dump_amqp_host, config.bgp_table_dump_amqp_exchange_type);
   p_amqp_set_host(&bgp_table_dump_amqp_host, config.bgp_table_dump_amqp_host);
+  p_amqp_set_vhost(&bgp_table_dump_amqp_host, config.bgp_table_dump_amqp_vhost);
   p_amqp_set_persistent_msg(&bgp_table_dump_amqp_host, config.bgp_table_dump_amqp_persistent_msg);
   p_amqp_set_frame_max(&bgp_table_dump_amqp_host, config.bgp_table_dump_amqp_frame_max);
+  p_amqp_set_heartbeat_interval(&bgp_table_dump_amqp_host, config.bgp_table_dump_amqp_heartbeat_interval);
 }
 #else
 void bgp_table_dump_init_amqp_host()
