@@ -1,6 +1,6 @@
 /*
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2014 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2015 by Paolo Lucente
 */
 
 /*
@@ -88,6 +88,9 @@ EXT int cfg_key_mongo_insert_batch(char *, char *, char *);
 EXT int cfg_key_amqp_exchange_type(char *, char *, char *);
 EXT int cfg_key_amqp_persistent_msg(char *, char *, char *);
 EXT int cfg_key_amqp_frame_max(char *, char *, char *);
+EXT int cfg_key_amqp_heartbeat_interval(char *, char *, char *);
+EXT int cfg_key_amqp_vhost(char *, char *, char *);
+EXT int cfg_key_amqp_routing_key_rr(char *, char *, char *);
 EXT int cfg_key_plugin_pipe_size(char *, char *, char *);
 EXT int cfg_key_plugin_pipe_backlog(char *, char *, char *);
 EXT int cfg_key_plugin_buffer_size(char *, char *, char *);
@@ -115,6 +118,7 @@ EXT int cfg_key_nfacctd_mcast_groups(char *, char *, char *);
 EXT int cfg_key_nfacctd_pipe_size(char *, char *, char *);
 EXT int cfg_key_nfacctd_pro_rating(char *, char *, char *);
 EXT int cfg_key_nfacctd_account_options(char *, char *, char *);
+EXT int cfg_key_nfacctd_stitching(char *, char *, char *);
 EXT int cfg_key_pmacctd_force_frag_handling(char *, char *, char *);
 EXT int cfg_key_pmacctd_frag_buffer_size(char *, char *, char *);
 EXT int cfg_key_pmacctd_flow_buffer_size(char *, char *, char *);
@@ -132,6 +136,7 @@ EXT int cfg_key_maps_row_len(char *, char *, char *);
 EXT int cfg_key_pre_tag_map(char *, char *, char *);
 EXT int cfg_key_pre_tag_filter(char *, char *, char *);
 EXT int cfg_key_pre_tag2_filter(char *, char *, char *);
+EXT int cfg_key_pre_tag_label_filter(char *, char *, char *);
 EXT int cfg_key_post_tag(char *, char *, char *);
 EXT int cfg_key_post_tag2(char *, char *, char *);
 EXT int cfg_key_sampling_rate(char *, char *, char *);
@@ -158,20 +163,25 @@ EXT int cfg_key_tee_receivers(char *, char *, char *);
 EXT int cfg_key_tee_transparent(char *, char *, char *);
 EXT int cfg_key_tee_max_receivers(char *, char *, char *);
 EXT int cfg_key_tee_max_receiver_pools(char *, char *, char *);
+EXT int cfg_key_tee_pipe_size(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_msglog_output(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_msglog_file(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_msglog_amqp_host(char *, char *, char *);
+EXT int cfg_key_nfacctd_bgp_msglog_amqp_vhost(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_msglog_amqp_user(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_msglog_amqp_passwd(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_msglog_amqp_exchange(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_msglog_amqp_exchange_type(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_msglog_amqp_routing_key(char *, char *, char *);
+EXT int cfg_key_nfacctd_bgp_msglog_amqp_routing_key_rr(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_msglog_amqp_persistent_msg(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_msglog_amqp_frame_max(char *, char *, char *);
+EXT int cfg_key_nfacctd_bgp_msglog_amqp_heartbeat_interval(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_msglog_amqp_retry(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_max_peers(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_ip(char *, char *, char *);
+EXT int cfg_key_nfacctd_bgp_id(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_port(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_ip_precedence(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_allow_file(char *, char *, char *);
@@ -202,16 +212,61 @@ EXT int cfg_key_nfacctd_bgp_table_dump_output(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_table_dump_file(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_table_dump_refresh_time(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_table_dump_amqp_host(char *, char *, char *);
+EXT int cfg_key_nfacctd_bgp_table_dump_amqp_vhost(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_table_dump_amqp_user(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_table_dump_amqp_passwd(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_table_dump_amqp_exchange(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_table_dump_amqp_exchange_type(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_table_dump_amqp_routing_key(char *, char *, char *);
+EXT int cfg_key_nfacctd_bgp_table_dump_amqp_routing_key_rr(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_table_dump_amqp_persistent_msg(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_table_dump_amqp_frame_max(char *, char *, char *);
+EXT int cfg_key_nfacctd_bgp_table_dump_amqp_heartbeat_interval(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_batch(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_batch_interval(char *, char *, char *);
 EXT int cfg_key_nfacctd_bgp_pipe_size(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_ip(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_port(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_pipe_size(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_max_peers(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_allow_file(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_ip_precedence(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_batch(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_batch_interval(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_neighbors_file(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_msglog_output(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_msglog_file(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_msglog_amqp_host(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_msglog_amqp_vhost(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_msglog_amqp_user(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_msglog_amqp_passwd(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_msglog_amqp_exchange(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_msglog_amqp_exchange_type(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_msglog_amqp_routing_key(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_msglog_amqp_routing_key_rr(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_msglog_amqp_persistent_msg(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_msglog_amqp_frame_max(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_msglog_amqp_heartbeat_interval(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_msglog_amqp_retry(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_table_peer_buckets(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_table_per_peer_buckets(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_table_attr_hash_buckets(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_table_per_peer_hash(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_dump_output(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_dump_file(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_dump_refresh_time(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_dump_amqp_host(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_dump_amqp_vhost(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_dump_amqp_user(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_dump_amqp_passwd(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_dump_amqp_exchange(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_dump_amqp_exchange_type(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_dump_amqp_routing_key(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_dump_amqp_routing_key_rr(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_dump_amqp_persistent_msg(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_dump_amqp_frame_max(char *, char *, char *);
+EXT int cfg_key_nfacctd_bmp_dump_amqp_heartbeat_interval(char *, char *, char *);
 EXT int cfg_key_nfacctd_flow_to_rd_map(char *, char *, char *);
 EXT int cfg_key_nfacctd_isis(char *, char *, char *);
 EXT int cfg_key_nfacctd_isis_ip(char *, char *, char *);
@@ -227,6 +282,7 @@ EXT int cfg_key_uacctd_group(char *, char *, char *);
 EXT int cfg_key_uacctd_nl_size(char *, char *, char *);
 EXT int cfg_key_tunnel_0(char *, char *, char *);
 EXT int cfg_key_pkt_len_distrib_bins(char *, char *, char *);
+EXT int cfg_key_tmp_net_own_field(char *, char *, char *);
 
 EXT void parse_time(char *, char *, int *, int *);
 EXT void cfg_set_aggregate(char *, u_int64_t [], u_int64_t, char *);
