@@ -1,6 +1,6 @@
 /*
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2014 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2015 by Paolo Lucente
 */
 
 /*
@@ -385,6 +385,7 @@ static const struct _dictionary_line dictionary[] = {
   {"print_max_writers", cfg_key_sql_max_writers},
   {"print_preprocess", cfg_key_sql_preprocess},
   {"print_preprocess_type", cfg_key_sql_preprocess_type},
+  {"print_startup_delay", cfg_key_sql_startup_delay},
   {"mongo_host", cfg_key_sql_host},
   {"mongo_table", cfg_key_sql_table},
   {"mongo_user", cfg_key_sql_user},
@@ -401,6 +402,8 @@ static const struct _dictionary_line dictionary[] = {
   {"mongo_max_writers", cfg_key_sql_max_writers},
   {"mongo_preprocess", cfg_key_sql_preprocess},
   {"mongo_preprocess_type", cfg_key_sql_preprocess_type},
+  {"mongo_startup_delay", cfg_key_sql_startup_delay},
+  {"mongo_num_protos", cfg_key_num_protos},
   {"amqp_refresh_time", cfg_key_sql_refresh_time},
   {"amqp_history", cfg_key_sql_history},
   {"amqp_history_offset", cfg_key_sql_history_offset},
@@ -412,12 +415,18 @@ static const struct _dictionary_line dictionary[] = {
   {"amqp_exchange", cfg_key_sql_db},
   {"amqp_exchange_type", cfg_key_amqp_exchange_type},
   {"amqp_routing_key", cfg_key_sql_table},
+  {"amqp_routing_key_rr", cfg_key_amqp_routing_key_rr},
   {"amqp_persistent_msg", cfg_key_amqp_persistent_msg},
   {"amqp_frame_max", cfg_key_amqp_frame_max},
   {"amqp_cache_entries", cfg_key_print_cache_entries},
   {"amqp_max_writers", cfg_key_sql_max_writers},
   {"amqp_preprocess", cfg_key_sql_preprocess},
   {"amqp_preprocess_type", cfg_key_sql_preprocess_type},
+  {"amqp_startup_delay", cfg_key_sql_startup_delay},
+  {"amqp_heartbeat_interval", cfg_key_amqp_heartbeat_interval},
+  {"amqp_multi_values", cfg_key_sql_multi_values},
+  {"amqp_num_protos", cfg_key_num_protos},
+  {"amqp_vhost", cfg_key_amqp_vhost},
   {"nfacctd_proc_name", cfg_key_proc_name},
   {"nfacctd_port", cfg_key_nfacctd_port},
   {"nfacctd_ip", cfg_key_nfacctd_ip},
@@ -431,6 +440,10 @@ static const struct _dictionary_line dictionary[] = {
   {"nfacctd_pipe_size", cfg_key_nfacctd_pipe_size},
   {"nfacctd_pro_rating", cfg_key_nfacctd_pro_rating},
   {"nfacctd_account_options", cfg_key_nfacctd_account_options},
+  {"nfacctd_stitching", cfg_key_nfacctd_stitching},
+  {"nfacctd_ext_sampling_rate", cfg_key_pmacctd_ext_sampling_rate},
+  {"nfacctd_renormalize", cfg_key_sfacctd_renormalize},
+  {"nfacctd_disable_checks", cfg_key_nfacctd_disable_checks},
   {"pmacctd_proc_name", cfg_key_proc_name},
   {"pmacctd_force_frag_handling", cfg_key_pmacctd_force_frag_handling},
   {"pmacctd_frag_buffer_size", cfg_key_pmacctd_frag_buffer_size},
@@ -441,6 +454,8 @@ static const struct _dictionary_line dictionary[] = {
   {"pmacctd_flow_tcp_lifetime", cfg_key_pmacctd_flow_tcp_lifetime},
   {"pmacctd_ext_sampling_rate", cfg_key_pmacctd_ext_sampling_rate},
   {"pmacctd_pipe_size", cfg_key_nfacctd_pipe_size},
+  {"pmacctd_stitching", cfg_key_nfacctd_stitching},
+  {"pmacctd_renormalize", cfg_key_sfacctd_renormalize},
   {"uacctd_proc_name", cfg_key_proc_name},
   {"uacctd_force_frag_handling", cfg_key_pmacctd_force_frag_handling},
   {"uacctd_frag_buffer_size", cfg_key_pmacctd_frag_buffer_size},
@@ -450,8 +465,8 @@ static const struct _dictionary_line dictionary[] = {
   {"uacctd_flow_lifetime", cfg_key_pmacctd_flow_lifetime},
   {"uacctd_flow_tcp_lifetime", cfg_key_pmacctd_flow_tcp_lifetime},
   {"uacctd_ext_sampling_rate", cfg_key_pmacctd_ext_sampling_rate},
-  {"nfacctd_ext_sampling_rate", cfg_key_pmacctd_ext_sampling_rate},
-  {"sfacctd_ext_sampling_rate", cfg_key_pmacctd_ext_sampling_rate},
+  {"uacctd_stitching", cfg_key_nfacctd_stitching},
+  {"uacctd_renormalize", cfg_key_sfacctd_renormalize},
   {"pcap_savefile", cfg_key_pcap_savefile},
   {"refresh_maps", cfg_key_maps_refresh}, // legacy
   {"maps_refresh", cfg_key_maps_refresh},
@@ -462,6 +477,7 @@ static const struct _dictionary_line dictionary[] = {
   {"pre_tag_map_entries", cfg_key_maps_entries}, // legacy	
   {"pre_tag_filter", cfg_key_pre_tag_filter},
   {"pre_tag2_filter", cfg_key_pre_tag2_filter},
+  {"pre_tag_label_filter", cfg_key_pre_tag_label_filter},
   {"post_tag", cfg_key_post_tag},
   {"post_tag2", cfg_key_post_tag2},
   {"sampling_rate", cfg_key_sampling_rate},
@@ -474,13 +490,11 @@ static const struct _dictionary_line dictionary[] = {
   {"sfacctd_net", cfg_key_nfacctd_net},
   {"sfacctd_peer_as", cfg_key_nfprobe_peer_as},
   {"sfacctd_pipe_size", cfg_key_nfacctd_pipe_size},
-  {"uacctd_renormalize", cfg_key_sfacctd_renormalize},
-  {"pmacctd_renormalize", cfg_key_sfacctd_renormalize},
   {"sfacctd_renormalize", cfg_key_sfacctd_renormalize},
-  {"nfacctd_renormalize", cfg_key_sfacctd_renormalize},
-  {"nfacctd_disable_checks", cfg_key_nfacctd_disable_checks},
   {"sfacctd_disable_checks", cfg_key_nfacctd_disable_checks},
   {"sfacctd_mcast_groups", cfg_key_nfacctd_mcast_groups},
+  {"sfacctd_stitching", cfg_key_nfacctd_stitching},
+  {"sfacctd_ext_sampling_rate", cfg_key_pmacctd_ext_sampling_rate},
   {"classifiers", cfg_key_classifiers},
   {"classifier_tentatives", cfg_key_classifier_tentatives},
   {"classifier_table_num", cfg_key_classifier_table_num},
@@ -509,21 +523,27 @@ static const struct _dictionary_line dictionary[] = {
   {"tee_transparent", cfg_key_tee_transparent},
   {"tee_max_receivers", cfg_key_tee_max_receivers},
   {"tee_max_receiver_pools", cfg_key_tee_max_receiver_pools},
+  {"tee_ipprec", cfg_key_nfprobe_ip_precedence},
+  {"tee_pipe_size", cfg_key_tee_pipe_size},
   {"bgp_daemon", cfg_key_nfacctd_bgp},
   {"bgp_daemon_ip", cfg_key_nfacctd_bgp_ip},
+  {"bgp_daemon_id", cfg_key_nfacctd_bgp_id},
   {"bgp_daemon_port", cfg_key_nfacctd_bgp_port},
   {"bgp_daemon_pipe_size", cfg_key_nfacctd_bgp_pipe_size},
   {"bgp_daemon_max_peers", cfg_key_nfacctd_bgp_max_peers},
   {"bgp_daemon_msglog_output", cfg_key_nfacctd_bgp_msglog_output},
   {"bgp_daemon_msglog_file", cfg_key_nfacctd_bgp_msglog_file},
   {"bgp_daemon_msglog_amqp_host", cfg_key_nfacctd_bgp_msglog_amqp_host},
+  {"bgp_daemon_msglog_amqp_vhost", cfg_key_nfacctd_bgp_msglog_amqp_vhost},
   {"bgp_daemon_msglog_amqp_user", cfg_key_nfacctd_bgp_msglog_amqp_user},
   {"bgp_daemon_msglog_amqp_passwd", cfg_key_nfacctd_bgp_msglog_amqp_passwd},
   {"bgp_daemon_msglog_amqp_exchange", cfg_key_nfacctd_bgp_msglog_amqp_exchange},
   {"bgp_daemon_msglog_amqp_exchange_type", cfg_key_nfacctd_bgp_msglog_amqp_exchange_type},
   {"bgp_daemon_msglog_amqp_routing_key", cfg_key_nfacctd_bgp_msglog_amqp_routing_key},
+  {"bgp_daemon_msglog_amqp_routing_key_rr", cfg_key_nfacctd_bgp_msglog_amqp_routing_key_rr},
   {"bgp_daemon_msglog_amqp_persistent_msg", cfg_key_nfacctd_bgp_msglog_amqp_persistent_msg},
   {"bgp_daemon_msglog_amqp_frame_max", cfg_key_nfacctd_bgp_msglog_amqp_frame_max},
+  {"bgp_daemon_msglog_amqp_heartbeat_interval", cfg_key_nfacctd_bgp_msglog_amqp_heartbeat_interval},
   {"bgp_daemon_msglog_amqp_retry", cfg_key_nfacctd_bgp_msglog_amqp_retry},
   {"bgp_daemon_allow_file", cfg_key_nfacctd_bgp_allow_file},
   {"bgp_daemon_ipprec", cfg_key_nfacctd_bgp_ip_precedence},
@@ -556,13 +576,58 @@ static const struct _dictionary_line dictionary[] = {
   {"bgp_table_dump_file", cfg_key_nfacctd_bgp_table_dump_file},
   {"bgp_table_dump_refresh_time", cfg_key_nfacctd_bgp_table_dump_refresh_time},
   {"bgp_table_dump_amqp_host", cfg_key_nfacctd_bgp_table_dump_amqp_host},
+  {"bgp_table_dump_amqp_vhost", cfg_key_nfacctd_bgp_table_dump_amqp_vhost},
   {"bgp_table_dump_amqp_user", cfg_key_nfacctd_bgp_table_dump_amqp_user},
   {"bgp_table_dump_amqp_passwd", cfg_key_nfacctd_bgp_table_dump_amqp_passwd},
   {"bgp_table_dump_amqp_exchange", cfg_key_nfacctd_bgp_table_dump_amqp_exchange},
   {"bgp_table_dump_amqp_exchange_type", cfg_key_nfacctd_bgp_table_dump_amqp_exchange_type},
   {"bgp_table_dump_amqp_routing_key", cfg_key_nfacctd_bgp_table_dump_amqp_routing_key},
+  {"bgp_table_dump_amqp_routing_key_rr", cfg_key_nfacctd_bgp_table_dump_amqp_routing_key_rr},
   {"bgp_table_dump_amqp_persistent_msg", cfg_key_nfacctd_bgp_table_dump_amqp_persistent_msg},
   {"bgp_table_dump_amqp_frame_max", cfg_key_nfacctd_bgp_table_dump_amqp_frame_max},
+  {"bgp_table_dump_amqp_heartbeat_interval", cfg_key_nfacctd_bgp_table_dump_amqp_heartbeat_interval},
+  {"bmp_daemon", cfg_key_nfacctd_bmp},
+  {"bmp_daemon_ip", cfg_key_nfacctd_bmp_ip},
+  {"bmp_daemon_port", cfg_key_nfacctd_bmp_port},
+  {"bmp_daemon_pipe_size", cfg_key_nfacctd_bmp_pipe_size},
+  {"bmp_daemon_max_peers", cfg_key_nfacctd_bmp_max_peers},
+  {"bmp_daemon_allow_file", cfg_key_nfacctd_bmp_allow_file},
+  {"bmp_daemon_ipprec", cfg_key_nfacctd_bmp_ip_precedence},
+  {"bmp_daemon_batch", cfg_key_nfacctd_bmp_batch},
+  {"bmp_daemon_batch_interval", cfg_key_nfacctd_bmp_batch_interval},
+  {"bmp_daemon_msglog_output", cfg_key_nfacctd_bmp_msglog_output},
+  {"bmp_daemon_msglog_file", cfg_key_nfacctd_bmp_msglog_file},
+  {"bmp_daemon_msglog_amqp_host", cfg_key_nfacctd_bmp_msglog_amqp_host},
+  {"bmp_daemon_msglog_amqp_vhost", cfg_key_nfacctd_bmp_msglog_amqp_vhost},
+  {"bmp_daemon_msglog_amqp_user", cfg_key_nfacctd_bmp_msglog_amqp_user},
+  {"bmp_daemon_msglog_amqp_passwd", cfg_key_nfacctd_bmp_msglog_amqp_passwd},
+  {"bmp_daemon_msglog_amqp_exchange", cfg_key_nfacctd_bmp_msglog_amqp_exchange},
+  {"bmp_daemon_msglog_amqp_exchange_type", cfg_key_nfacctd_bmp_msglog_amqp_exchange_type},
+  {"bmp_daemon_msglog_amqp_routing_key", cfg_key_nfacctd_bmp_msglog_amqp_routing_key},
+  {"bmp_daemon_msglog_amqp_routing_key_rr", cfg_key_nfacctd_bmp_msglog_amqp_routing_key_rr},
+  {"bmp_daemon_msglog_amqp_persistent_msg", cfg_key_nfacctd_bmp_msglog_amqp_persistent_msg},
+  {"bmp_daemon_msglog_amqp_frame_max", cfg_key_nfacctd_bmp_msglog_amqp_frame_max},
+  {"bmp_daemon_msglog_amqp_heartbeat_interval", cfg_key_nfacctd_bmp_msglog_amqp_heartbeat_interval},
+  {"bmp_daemon_msglog_amqp_retry", cfg_key_nfacctd_bmp_msglog_amqp_retry},
+  {"bmp_neighbors_file", cfg_key_nfacctd_bmp_neighbors_file},
+  {"bmp_table_peer_buckets", cfg_key_nfacctd_bmp_table_peer_buckets},
+  {"bmp_table_per_peer_buckets", cfg_key_nfacctd_bmp_table_per_peer_buckets},
+  {"bmp_table_attr_hash_buckets", cfg_key_nfacctd_bmp_table_attr_hash_buckets},
+  {"bmp_table_per_peer_hash", cfg_key_nfacctd_bmp_table_per_peer_hash},
+  {"bmp_dump_output", cfg_key_nfacctd_bmp_dump_output},
+  {"bmp_dump_file", cfg_key_nfacctd_bmp_dump_file},
+  {"bmp_dump_refresh_time", cfg_key_nfacctd_bmp_dump_refresh_time},
+  {"bmp_dump_amqp_host", cfg_key_nfacctd_bmp_dump_amqp_host},
+  {"bmp_dump_amqp_vhost", cfg_key_nfacctd_bmp_dump_amqp_vhost},
+  {"bmp_dump_amqp_user", cfg_key_nfacctd_bmp_dump_amqp_user},
+  {"bmp_dump_amqp_passwd", cfg_key_nfacctd_bmp_dump_amqp_passwd},
+  {"bmp_dump_amqp_exchange", cfg_key_nfacctd_bmp_dump_amqp_exchange},
+  {"bmp_dump_amqp_exchange_type", cfg_key_nfacctd_bmp_dump_amqp_exchange_type},
+  {"bmp_dump_amqp_routing_key", cfg_key_nfacctd_bmp_dump_amqp_routing_key},
+  {"bmp_dump_amqp_routing_key_rr", cfg_key_nfacctd_bmp_dump_amqp_routing_key_rr},
+  {"bmp_dump_amqp_persistent_msg", cfg_key_nfacctd_bmp_dump_amqp_persistent_msg},
+  {"bmp_dump_amqp_frame_max", cfg_key_nfacctd_bmp_dump_amqp_frame_max},
+  {"bmp_dump_amqp_heartbeat_interval", cfg_key_nfacctd_bmp_dump_amqp_heartbeat_interval},
   {"flow_to_rd_map", cfg_key_nfacctd_flow_to_rd_map},
   {"isis_daemon", cfg_key_nfacctd_isis},
   {"isis_daemon_ip", cfg_key_nfacctd_isis_ip},
@@ -583,6 +648,7 @@ static const struct _dictionary_line dictionary[] = {
   {"uacctd_nl_size", cfg_key_uacctd_nl_size},
   {"tunnel_0", cfg_key_tunnel_0},
   {"pkt_len_distrib_bins", cfg_key_pkt_len_distrib_bins},
+  {"tmp_net_own_field", cfg_key_tmp_net_own_field},
   {"", NULL},
 };
 
