@@ -1,6 +1,6 @@
 /*
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2014 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2015 by Paolo Lucente
 */
 
 /*
@@ -29,38 +29,40 @@
 #define ID_TABLE_INDEX_DEPTH 8
 #define ID_TABLE_INDEX_RESULTS (MAX_ID_TABLE_INDEXES * 8)
 
-#define PRETAG_IN_IFACE			0x00000001
-#define PRETAG_OUT_IFACE		0x00000002
-#define PRETAG_NEXTHOP			0x00000004
-#define PRETAG_BGP_NEXTHOP		0x00000008
-#define PRETAG_ENGINE_TYPE		0x00000010
-#define PRETAG_ENGINE_ID		0x00000020
-#define PRETAG_FILTER			0x00000040
-#define PRETAG_NFV8_AGG			0x00000080
-#define PRETAG_SF_AGENTID		0x00000100
-#define PRETAG_SAMPLING_RATE		0x00000200
-#define PRETAG_DIRECTION		0x00000400
-#define PRETAG_SRC_AS			0x00000800
-#define PRETAG_DST_AS			0x00001000
-#define PRETAG_PEER_SRC_AS		0x00002000
-#define PRETAG_PEER_DST_AS		0x00004000
-#define PRETAG_SRC_LOCAL_PREF		0x00008000
-#define PRETAG_LOCAL_PREF		0x00010000
-#define PRETAG_SRC_STD_COMM		0x00020000
-#define PRETAG_STD_COMM			0x00040000
-#define PRETAG_MPLS_VPN_RD		0x00080000
-#define PRETAG_SAMPLE_TYPE      	0x00100000
-#define PRETAG_SET_TOS			0x00200000
-#define PRETAG_LOOKUP_BGP_PORT		0x00400000
-#define PRETAG_SET_TAG			0x00800000
-#define PRETAG_SET_TAG2			0x01000000
-#define PRETAG_MPLS_LABEL_BOTTOM	0x02000000
-#define PRETAG_FLOWSET_ID		0x04000000
-#define PRETAG_SRC_MAC			0x08000000
-#define PRETAG_VLAN_ID			0x10000000
-#define PRETAG_IP			0x20000000
-#define PRETAG_MPLS_PW_ID		0x40000000
-#define PRETAG_SET_LABEL		0x80000000
+#define PRETAG_IN_IFACE			0x000000001
+#define PRETAG_OUT_IFACE		0x000000002
+#define PRETAG_NEXTHOP			0x000000004
+#define PRETAG_BGP_NEXTHOP		0x000000008
+#define PRETAG_ENGINE_TYPE		0x000000010
+#define PRETAG_ENGINE_ID		0x000000020
+#define PRETAG_FILTER			0x000000040
+#define PRETAG_NFV8_AGG			0x000000080
+#define PRETAG_SF_AGENTID		0x000000100
+#define PRETAG_SAMPLING_RATE		0x000000200
+#define PRETAG_DIRECTION		0x000000400
+#define PRETAG_SRC_AS			0x000000800
+#define PRETAG_DST_AS			0x000001000
+#define PRETAG_PEER_SRC_AS		0x000002000
+#define PRETAG_PEER_DST_AS		0x000004000
+#define PRETAG_SRC_LOCAL_PREF		0x000008000
+#define PRETAG_LOCAL_PREF		0x000010000
+#define PRETAG_SRC_STD_COMM		0x000020000
+#define PRETAG_STD_COMM			0x000040000
+#define PRETAG_MPLS_VPN_RD		0x000080000
+#define PRETAG_SAMPLE_TYPE      	0x000100000
+#define PRETAG_SET_TOS			0x000200000
+#define PRETAG_LOOKUP_BGP_PORT		0x000400000
+#define PRETAG_SET_TAG			0x000800000
+#define PRETAG_SET_TAG2			0x001000000
+#define PRETAG_MPLS_LABEL_BOTTOM	0x002000000
+#define PRETAG_FLOWSET_ID		0x004000000
+#define PRETAG_SRC_MAC			0x008000000
+#define PRETAG_DST_MAC			0x010000000
+#define PRETAG_VLAN_ID			0x020000000
+#define PRETAG_IP			0x040000000
+#define PRETAG_SET_LABEL		0x080000000
+#define PRETAG_MPLS_PW_ID		0x100000000
+#define PRETAG_CVLAN_ID			0x200000000
 
 #define PRETAG_MAP_RCODE_ID		0x00000100
 #define PRETAG_MAP_RCODE_ID2		0x00000200
@@ -128,6 +130,13 @@ typedef struct {
   pm_id_t r;
 } ptt_t;
 
+/* Pre-Tag label table (ptlt) element definition */
+typedef struct {
+  u_int8_t neg;
+  u_int32_t len;
+  char *v;
+} ptlt_t;
+
 struct id_entry {
   pm_id_t id;
   pm_id_t id2;
@@ -155,7 +164,9 @@ struct id_entry {
   pt_uint32_t local_pref;
   pt_uint32_t mpls_label_bottom;
   pt_etheraddr_t src_mac;
+  pt_etheraddr_t dst_mac;
   pt_uint16_t vlan_id;
+  pt_uint16_t post_cvlan_id;
   s_uint8_t set_tos;
   s_uint16_t lookup_bgp_port;
   char *src_comms[16]; /* XXX: MAX_BGP_COMM_PATTERNS = 16 */
@@ -224,6 +235,11 @@ struct pretag_filter {
   ptt_t table[MAX_PRETAG_MAP_ENTRIES/4];
 };
 
+struct pretag_label_filter {
+  u_int16_t num;
+  ptlt_t table[MAX_PRETAG_MAP_ENTRIES/4];
+};
+
 /* prototypes */
 #if (!defined __PRETAG_C)
 #define EXT extern
