@@ -440,6 +440,10 @@ void process_query_data(int sd, unsigned char *buf, int len, struct extra_primit
     enQueue_elem(sd, &rb, &dummy, sizeof(dummy), sizeof(dummy));
     if (rb.packed) send(sd, rb.buf, rb.packed, 0); /* send remainder data */
   }
+  else if (q->type & WANT_ERASE_LAST_TSTAMP) {
+    enQueue_elem(sd, &rb, &table_reset_stamp, sizeof(table_reset_stamp), sizeof(table_reset_stamp));
+    if (rb.packed) send(sd, rb.buf, rb.packed, 0); /* send remainder data */
+  }
 
   /* wait a bit due to setnonblocking() then send EOF */
   usleep(1000);
@@ -473,8 +477,10 @@ void mask_elem(struct pkt_primitives *d1, struct pkt_bgp_primitives *d2, struct
   if (w & COUNT_COS) d1->cos = s1->cos; 
   if (w & COUNT_ETHERTYPE) d1->etype = s1->etype; 
 #endif
-  if (w & (COUNT_SRC_HOST|COUNT_SRC_NET)) memcpy(&d1->src_ip, &s1->src_ip, sizeof(d1->src_ip));
-  if (w & (COUNT_DST_HOST|COUNT_DST_NET)) memcpy(&d1->dst_ip, &s1->dst_ip, sizeof(d1->dst_ip));
+  if (w & COUNT_SRC_HOST) memcpy(&d1->src_ip, &s1->src_ip, sizeof(d1->src_ip));
+  if (w & COUNT_DST_HOST) memcpy(&d1->dst_ip, &s1->dst_ip, sizeof(d1->dst_ip));
+  if (w & COUNT_SRC_NET) memcpy(&d1->src_net, &s1->src_net, sizeof(d1->src_net));
+  if (w & COUNT_DST_NET) memcpy(&d1->dst_net, &s1->dst_net, sizeof(d1->dst_net));
   if (w & COUNT_SRC_NMASK) d1->src_nmask = s1->src_nmask; 
   if (w & COUNT_DST_NMASK) d1->dst_nmask = s1->dst_nmask; 
   if (w & COUNT_SRC_AS) d1->src_as = s1->src_as; 
